Crate rktk_drivers_nrf

rktk-driver-nrf

rktk drivers for nrf chip

For more detail, see RKTK project README This crate provides the rktk drivers for the nRF series microcontrollers. Currently, only nRF52840 is enabled, but it should be easy to add support for other nRF series microcontrollers.

Many drivers is in this crate are just convenient wrappers over rktk_drivers_common, but implements some original drivers like BLE and Uart split driver.

NOTE: This crate uses unreleased version of nrf-softdevice and such dependency is not accepted by crates.io. So if you want to use softdevice feature (needed for BLE), use git version of this crate.

Modules

display
keyscan
mouse
rgb
split
system
usb